Podcast downloader
##################

This is a really simple script you can use to download all the files linked in
an RSS podcast.

It's not made to track new podcast releases nor to respect all the podcast
formats that exist. I made this because I wanted to get all the files of
a podcast I love, and I published it here just because.

Hmm… okay. How do I install / use this thing?
=============================================

Use pip to install::

    $ pip install podcastdl

And then just ::
    
    $ podcastdl http://parisdjs.libsyn.com/rss output
    Karl Hector - Soul Sauvage d'Afrique Vol.2: [   3% 312.18 kB/s]  of 66.0MB

